<?php
/**
 * @file
 * Implements UUID resolver on behalf of node module.
 */

/**
 * Implements hook_uuid_resolver_info().
 *
 * @ingroup uuid_resolver_hooks
 */
function node_uuid_resolver_info() {
  $resolvers['node'] = array(
    'title' => 'Node',
    'callback' => 'uuid_resolver_resolve_node',
    'callback arguments' => '',
  );
  $resolvers['node_revision'] = array(
    'title' => 'Node revision',
    'callback' => 'uuid_resolver_resolve_node_revision',
  );
  return $resolvers;
}

/**
 * Resolve UUID for a node path.
 *
 * @param string $uuid
 *   UUID of node.
 *
 * @return
 *   Path or alias to node, or nothing if none matched.
 *
 * @ingroup uuid_resolver_callbacks
 */
function uuid_resolver_resolve_node($uuid) {

  $match = db_select('node', 'n')
    ->fields('n', array('nid'))
    ->condition('uuid', $uuid)
    ->execute()
    ->fetchAssoc();

  //$nid = db_result(db_query("SELECT nid FROM {uuid_node} WHERE uuid = '%s'", $uuid));
  if (isset($match['nid'])) {
    $path = 'node/' . $match['nid'];
    if (variable_get('uuid_resolver_node_use_alias', FALSE)) {
      return drupal_get_path_alias($path);
    }
    else {
      return $path;
    }
  }
}

/**
 * Resolve UUID for a node revision path.
 *
 * @param string $uuid
 *   UUID of node revision.
 *
 * @return
 *   Path to node revision, or nothing if none matched.
 *
 * @ingroup uuid_resolver_callbacks
 */
function uuid_resolver_resolve_node_revision($uuid) {
  $match = db_select('node_revision', 'nr')
    ->fields('nr', array('nid', 'vid', 'vuuid'))
    ->condition('vuuid', $uuid)
    ->execute()
    ->fetchAssoc();

  if (isset($match['nid'])) {
    return 'node/' . $match['nid'] . '/revisions/' . $match['vid'] . '/view';
  }
}

/**
 * Implements hook_form_FORM_ID_alter() for uuid_resolver_node_settings_form().
 */
function node_form_uuid_resolver_node_settings_form_alter(&$form, &$form_state) {
  $form['#submit'][] = 'uuid_resolver_node_extra_settings_form_submit';
  $form['use_alias'] = array(
    '#title' => t('Redirect to path alias.'),
    '#description' => t('If checked, the resolver will redirect to the aliased path instead of the system path.'),
    '#type' => 'checkbox',
    '#default_value' => variable_get('uuid_resolver_node_use_alias', FALSE),
  );
}

/**
 * Form submit handler.
 */
function uuid_resolver_node_extra_settings_form_submit($form, $form_state) {
  $values = $form_state['values'];
  variable_set('uuid_resolver_node_use_alias', (bool) $values['use_alias']);
}
